@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: typemod.ml,v 1.73 2005/08/08 09:41:51 xleroy Exp $ *)
+(* $Id: typemod.ml,v 1.73.2.1 2006/04/21 06:18:51 garrigue Exp $ *)
 
 (* Type-checking of the module language *)
 
@@ -95,7 +95,8 @@ let merge_constraint initial_env loc sg lid constr =
 	    type_kind = Type_abstract;
 	    type_manifest = None;
 	    type_variance =
-	      List.map (fun (c,n) -> (c,n,n)) sdecl.ptype_variance }
+	      List.map (fun (c,n) -> (not n, not c, not c))
+	      sdecl.ptype_variance }
 	and id_row = Ident.create (s^"#row") in
 	let initial_env = Env.add_type id_row decl_row initial_env in
         let newdecl = Typedecl.transl_with_constraint
